@@ -27,4 +27,4 @@ URL_ROOT = "https://api.servicetitan.io"
 
 from servicepytan.requests import Endpoint
 from servicepytan.data import DataService
-from servicepytan.dates import convert_date_to_api_format
+from servicepytan._dates import _convert_date_to_api_format
